@@ -15,7 +15,7 @@ from typing import Union, Callable, Optional, Mapping, Any, Dict, Tuple
 import numpy as np
 from numpy import random
 from scipy import sparse
-from anndata import AnnData
+from anndata import AnnData, __version__ as anndata_version
 from textwrap import dedent
 from packaging import version
 
@@ -36,19 +36,12 @@ AnyRandom = Union[None, int, random.RandomState]  # maybe in the future random.G
 EPS = 1e-15
 
 
-def pkg_version(package):
-    try:
-        from importlib.metadata import version as v
-    except ImportError:  # < Python 3.8: Use backport module
-        from importlib_metadata import version as v
-    return version.parse(v(package))
-
-
 def check_versions():
-    anndata_version = pkg_version("anndata")
+    from ._compat import pkg_version
+
     umap_version = pkg_version("umap-learn")
 
-    if anndata_version < version.parse('0.6.10'):
+    if version.parse(anndata_version) < version.parse('0.6.10'):
         from . import __version__
 
         raise ImportError(
@@ -183,6 +176,21 @@ def _check_array_function_arguments(**kwargs):
         )
 
 
+def _check_use_raw(adata: AnnData, use_raw: Union[None, bool]) -> bool:
+    """
+    Normalize checking `use_raw`.
+
+    My intentention here is to also provide a single place to throw a deprecation warning from in future.
+    """
+    if use_raw is not None:
+        return use_raw
+    else:
+        if adata.raw is not None:
+            return True
+        else:
+            return False
+
+
 # --------------------------------------------------------------------------------
 # Graph stuff
 # --------------------------------------------------------------------------------
@@ -201,7 +209,7 @@ def get_igraph_from_adjacency(adjacency, directed=None):
     g.add_edges(list(zip(sources, targets)))
     try:
         g.es['weight'] = weights
-    except:
+    except KeyError:
         pass
     if g.vcount() != adjacency.shape[0]:
         logg.warning(
@@ -386,13 +394,15 @@ def identify_groups(ref_labels, pred_labels, return_overlaps=False):
 
 # backwards compat... remove this in the future
 def sanitize_anndata(adata):
+    """Transform string annotations to categoricals."""
     adata._sanitize()
 
 
 def view_to_actual(adata):
     if adata.is_view:
         warnings.warn(
-            "Revieved a view of an AnnData. Making a copy.", stacklevel=2,
+            "Revieved a view of an AnnData. Making a copy.",
+            stacklevel=2,
         )
         adata._init_as_actual(adata.copy())
 
@@ -423,7 +433,9 @@ def moving_average(a: np.ndarray, n: int):
 
 
 def update_params(
-    old_params: Mapping[str, Any], new_params: Mapping[str, Any], check=False,
+    old_params: Mapping[str, Any],
+    new_params: Mapping[str, Any],
+    check=False,
 ) -> Dict[str, Any]:
     """\
     Update old_params with new_params.
@@ -465,8 +477,7 @@ def update_params(
 
 
 def check_nonnegative_integers(X: Union[np.ndarray, sparse.spmatrix]):
-    """Checks values of X to ensure it is count data
-    """
+    """Checks values of X to ensure it is count data"""
     from numbers import Integral
 
     data = X if isinstance(X, np.ndarray) else X.data
@@ -483,8 +494,7 @@ def check_nonnegative_integers(X: Union[np.ndarray, sparse.spmatrix]):
 
 
 def select_groups(adata, groups_order_subset='all', key='groups'):
-    """Get subset of groups in adata.obs[key].
-    """
+    """Get subset of groups in adata.obs[key]."""
     groups_order = adata.obs[key].cat.categories
     if key + '_masks' in adata.uns:
         groups_masks = adata.uns[key + '_masks']
@@ -541,12 +551,16 @@ def warn_with_traceback(message, category, filename, lineno, file=None, line=Non
     import traceback
 
     traceback.print_stack()
-    log = file if hasattr(file, 'write') else sys.stderr
+    log = (  # noqa: F841  # TODO Does this need fixing?
+        file if hasattr(file, 'write') else sys.stderr
+    )
     settings.write(warnings.formatwarning(message, category, filename, lineno, line))
 
 
 def subsample(
-    X: np.ndarray, subsample: int = 1, seed: int = 0,
+    X: np.ndarray,
+    subsample: int = 1,
+    seed: int = 0,
 ) -> Tuple[np.ndarray, np.ndarray]:
     """\
     Subsample a fraction of 1/subsample samples from the rows of X.
