@@ -6,7 +6,7 @@ import pandas as pd
 from scipy.sparse import spmatrix
 
 from anndata import AnnData
-import warnings
+from .._compat import Literal
 
 # --------------------------------------------------------------------------------
 # Plotting data helpers
@@ -96,7 +96,7 @@ def rank_genes_groups_df(
 def _check_indices(
     dim_df: pd.DataFrame,
     alt_index: pd.Index,
-    dim: "Literal['obs', 'var']",
+    dim: Literal['obs', 'var'],
     keys: List[str],
     alias_index: Optional[pd.Index] = None,
     use_raw: bool = False,
@@ -176,7 +176,7 @@ def _get_array_values(
     X,
     dim_names: pd.Index,
     keys: List[str],
-    axis: "Literal[0, 1]",
+    axis: Literal[0, 1],
     backed: bool,
 ):
     # TODO: This should be made easier on the anndata side
