@@ -32,12 +32,13 @@ class _RootLogger(logging.RootLogger):
         deep: Optional[str] = None,
     ) -> datetime:
         from . import settings
+
         now = datetime.now(timezone.utc)
         time_passed: timedelta = None if time is None else now - time
         extra = {
             **(extra or {}),
             'deep': deep if settings.verbosity.level < level else None,
-            'time_passed': time_passed
+            'time_passed': time_passed,
         }
         super().log(level, msg, extra=extra)
         return now
@@ -78,12 +79,14 @@ def _set_log_file(settings):
 def _set_log_level(settings, level: int):
     root = settings._root_logger
     root.setLevel(level)
-    h, = root.handlers  # may only be 1
+    (h,) = root.handlers  # may only be 1
     h.setLevel(level)
 
 
 class _LogFormatter(logging.Formatter):
-    def __init__(self, fmt='{levelname}: {message}', datefmt='%Y-%m-%d %H:%M', style='{'):
+    def __init__(
+        self, fmt='{levelname}: {message}', datefmt='%Y-%m-%d %H:%M', style='{'
+    ):
         super().__init__(fmt, datefmt, style)
 
     def format(self, record: logging.LogRecord):
@@ -97,9 +100,13 @@ class _LogFormatter(logging.Formatter):
         if record.time_passed:
             # strip microseconds
             if record.time_passed.microseconds:
-                record.time_passed = timedelta(seconds=int(record.time_passed.total_seconds()))
+                record.time_passed = timedelta(
+                    seconds=int(record.time_passed.total_seconds())
+                )
             if '{time_passed}' in record.msg:
-                record.msg = record.msg.replace('{time_passed}', str(record.time_passed))
+                record.msg = record.msg.replace(
+                    '{time_passed}', str(record.time_passed)
+                )
             else:
                 self._style._fmt += ' ({time_passed})'
         if record.deep:
@@ -145,10 +152,10 @@ def print_header(*, file=None):
     """
 
     modules = ['scanpy'] + _DEPENDENCIES_NUMERICS
-    print(' '.join(
-        f'{mod}=={ver}'
-        for mod, ver in _versions_dependencies(modules)
-    ), file=file or sys.stdout)
+    print(
+        ' '.join(f'{mod}=={ver}' for mod, ver in _versions_dependencies(modules)),
+        file=file or sys.stdout,
+    )
 
 
 def print_versions(*, file=None):
@@ -158,7 +165,17 @@ def print_versions(*, file=None):
     stdout = sys.stdout
     try:
         buf = sys.stdout = io.StringIO()
-        sinfo(dependencies=True)
+        sinfo(
+            dependencies=True,
+            excludes=[
+                'builtins',
+                'stdlib_list',
+                'importlib_metadata',
+                # Special module present if test coverage being calculated
+                # https://gitlab.com/joelostblom/sinfo/-/issues/10
+                "$coverage",
+            ],
+        )
     finally:
         sys.stdout = stdout
     output = buf.getvalue()
@@ -170,11 +187,11 @@ def print_version_and_date(*, file=None):
     Useful for starting a notebook so you see when you started working.
     """
     from . import __version__
+
     if file is None:
         file = sys.stdout
     print(
-        f'Running Scanpy {__version__}, '
-        f'on {datetime.now():%Y-%m-%d %H:%M}.',
+        f'Running Scanpy {__version__}, ' f'on {datetime.now():%Y-%m-%d %H:%M}.',
         file=file,
     )
 
@@ -209,28 +226,33 @@ def error(
         Additional values you can specify in `msg` like `{time_passed}`.
     """
     from ._settings import settings
+
     return settings._root_logger.error(msg, time=time, deep=deep, extra=extra)
 
 
 @_copy_docs_and_signature(error)
 def warning(msg, *, time=None, deep=None, extra=None) -> datetime:
     from ._settings import settings
+
     return settings._root_logger.warning(msg, time=time, deep=deep, extra=extra)
 
 
 @_copy_docs_and_signature(error)
 def info(msg, *, time=None, deep=None, extra=None) -> datetime:
     from ._settings import settings
+
     return settings._root_logger.info(msg, time=time, deep=deep, extra=extra)
 
 
 @_copy_docs_and_signature(error)
 def hint(msg, *, time=None, deep=None, extra=None) -> datetime:
     from ._settings import settings
+
     return settings._root_logger.hint(msg, time=time, deep=deep, extra=extra)
 
 
 @_copy_docs_and_signature(error)
 def debug(msg, *, time=None, deep=None, extra=None) -> datetime:
     from ._settings import settings
+
     return settings._root_logger.debug(msg, time=time, deep=deep, extra=extra)
