@@ -15,10 +15,10 @@ from .._compat import Literal
 from ..tools._utils import _choose_representation, doc_use_rep, doc_n_pcs
 from .. import settings
 
-
 N_DCS = 15  # default number of diffusion components
-N_PCS = settings.N_PCS  # Backwards compat, constants should be defined in only one place.
-
+N_PCS = (
+    settings.N_PCS
+)  # Backwards compat, constants should be defined in only one place.
 
 _Method = Literal['umap', 'gauss', 'rapids']
 _MetricFn = Callable[[np.ndarray, np.ndarray], float]
@@ -27,10 +27,23 @@ _MetricSparseCapable = Literal[
     'cityblock', 'cosine', 'euclidean', 'l1', 'l2', 'manhattan'
 ]
 _MetricScipySpatial = Literal[
-    'braycurtis', 'canberra', 'chebyshev', 'correlation', 'dice', 'hamming',
-    'jaccard', 'kulsinski', 'mahalanobis', 'minkowski', 'rogerstanimoto',
-    'russellrao', 'seuclidean', 'sokalmichener', 'sokalsneath', 'sqeuclidean',
-    'yule'
+    'braycurtis',
+    'canberra',
+    'chebyshev',
+    'correlation',
+    'dice',
+    'hamming',
+    'jaccard',
+    'kulsinski',
+    'mahalanobis',
+    'minkowski',
+    'rogerstanimoto',
+    'russellrao',
+    'seuclidean',
+    'sokalmichener',
+    'sokalsneath',
+    'sqeuclidean',
+    'yule',
 ]
 _Metric = Union[_MetricSparseCapable, _MetricScipySpatial]
 
@@ -111,6 +124,12 @@ def neighbors(
     **distances** : sparse matrix of dtype `float32`.
         Instead of decaying weights, this stores distances for each pair of
         neighbors.
+
+    Notes
+    -----
+    If `method='umap'`, it's highly recommended to install pynndescent ``pip install pynndescent``.
+    Installing `pynndescent` can significantly increase performance,
+    and in later versions it will become a hard dependency.
     """
     start = logg.info('computing neighbors')
     adata = adata.copy() if copy else adata
@@ -118,8 +137,13 @@ def neighbors(
         adata._init_as_actual(adata.copy())
     neighbors = Neighbors(adata)
     neighbors.compute_neighbors(
-        n_neighbors=n_neighbors, knn=knn, n_pcs=n_pcs, use_rep=use_rep,
-        method=method, metric=metric, metric_kwds=metric_kwds,
+        n_neighbors=n_neighbors,
+        knn=knn,
+        n_pcs=n_pcs,
+        use_rep=use_rep,
+        method=method,
+        metric=metric,
+        metric_kwds=metric_kwds,
         random_state=random_state,
     )
 
@@ -175,15 +199,17 @@ class FlatTree(NamedTuple):
 RPForestDict = Mapping[str, Mapping[str, np.ndarray]]
 
 
-def _rp_forest_generate(rp_forest_dict: RPForestDict) -> Generator[FlatTree, None, None]:
+def _rp_forest_generate(
+    rp_forest_dict: RPForestDict,
+) -> Generator[FlatTree, None, None]:
     props = FlatTree._fields
-    num_trees = len(rp_forest_dict[props[0]]['start'])-1
+    num_trees = len(rp_forest_dict[props[0]]['start']) - 1
 
     for i in range(num_trees):
         tree = []
         for prop in props:
             start = rp_forest_dict[prop]['start'][i]
-            end = rp_forest_dict[prop]['start'][i+1]
+            end = rp_forest_dict[prop]['start'][i + 1]
             tree.append(rp_forest_dict[prop]['data'][start:end])
         yield FlatTree(*tree)
 
@@ -277,18 +303,19 @@ def compute_neighbors_umap(
     random_state = check_random_state(random_state)
 
     knn_indices, knn_dists, forest = nearest_neighbors(
-        X, n_neighbors, random_state=random_state,
-        metric=metric, metric_kwds=metric_kwds,
-        angular=angular, verbose=verbose,
+        X,
+        n_neighbors,
+        random_state=random_state,
+        metric=metric,
+        metric_kwds=metric_kwds,
+        angular=angular,
+        verbose=verbose,
     )
 
     return knn_indices, knn_dists, forest
 
 
-def compute_neighbors_rapids(
-    X: np.ndarray,
-    n_neighbors: int
-):
+def compute_neighbors_rapids(X: np.ndarray, n_neighbors: int):
     """Compute nearest neighbors using RAPIDS cuml.
 
     Parameters
@@ -303,14 +330,17 @@ def compute_neighbors_rapids(
     **knn_indices**, **knn_dists** : np.arrays of shape (n_observations, n_neighbors)
     """
     from cuml.neighbors import NearestNeighbors
+
     nn = NearestNeighbors(n_neighbors=n_neighbors)
     X_contiguous = np.ascontiguousarray(X, dtype=np.float32)
     nn.fit(X_contiguous)
     knn_distsq, knn_indices = nn.kneighbors(X_contiguous)
-    return knn_indices, np.sqrt(knn_distsq) # cuml uses sqeuclidean metric so take sqrt
+    return knn_indices, np.sqrt(knn_distsq)  # cuml uses sqeuclidean metric so take sqrt
 
 
-def _get_sparse_matrix_from_indices_distances_umap(knn_indices, knn_dists, n_obs, n_neighbors):
+def _get_sparse_matrix_from_indices_distances_umap(
+    knn_indices, knn_dists, n_obs, n_neighbors
+):
     rows = np.zeros((n_obs * n_neighbors), dtype=np.int64)
     cols = np.zeros((n_obs * n_neighbors), dtype=np.int64)
     vals = np.zeros((n_obs * n_neighbors), dtype=np.float64)
@@ -328,15 +358,17 @@ def _get_sparse_matrix_from_indices_distances_umap(knn_indices, knn_dists, n_obs
             cols[i * n_neighbors + j] = knn_indices[i, j]
             vals[i * n_neighbors + j] = val
 
-    result = coo_matrix((vals, (rows, cols)),
-                                      shape=(n_obs, n_obs))
+    result = coo_matrix((vals, (rows, cols)), shape=(n_obs, n_obs))
     result.eliminate_zeros()
     return result.tocsr()
 
 
 def _compute_connectivities_umap(
-    knn_indices, knn_dists,
-    n_obs, n_neighbors, set_op_mix_ratio=1.0,
+    knn_indices,
+    knn_dists,
+    n_obs,
+    n_neighbors,
+    set_op_mix_ratio=1.0,
     local_connectivity=1.0,
 ):
     """\
@@ -377,14 +409,19 @@ def _compute_connectivities_umap(
     return distances, connectivities.tocsr()
 
 
-def _get_sparse_matrix_from_indices_distances_numpy(indices, distances, n_obs, n_neighbors):
+def _get_sparse_matrix_from_indices_distances_numpy(
+    indices, distances, n_obs, n_neighbors
+):
     n_nonzero = n_obs * n_neighbors
     indptr = np.arange(0, n_nonzero + 1, n_neighbors)
-    D = csr_matrix((
-        distances.copy().ravel(),  # copy the data, otherwise strange behavior here
-        indices.copy().ravel(),
-        indptr,
-    ), shape=(n_obs, n_obs))
+    D = csr_matrix(
+        (
+            distances.copy().ravel(),  # copy the data, otherwise strange behavior here
+            indices.copy().ravel(),
+            indptr,
+        ),
+        shape=(n_obs, n_obs),
+    )
     D.eliminate_zeros()
     return D
 
@@ -404,7 +441,8 @@ def _get_indices_distances_from_sparse_matrix(D, n_neighbors: int):
             sorted_indices = np.argsort(D[i][neighbors].A1)[:n_neighbors_m1]
             indices[i, 1:] = neighbors[1][sorted_indices]
             distances[i, 1:] = D[i][
-                neighbors[0][sorted_indices], neighbors[1][sorted_indices]]
+                neighbors[0][sorted_indices], neighbors[1][sorted_indices]
+            ]
         else:
             indices[i, 1:] = neighbors[1]
             distances[i, 1:] = D[i][neighbors]
@@ -413,7 +451,7 @@ def _get_indices_distances_from_sparse_matrix(D, n_neighbors: int):
 
 def _get_indices_distances_from_dense_matrix(D, n_neighbors: int):
     sample_range = np.arange(D.shape[0])[:, None]
-    indices = np.argpartition(D, n_neighbors-1, axis=1)[:, :n_neighbors]
+    indices = np.argpartition(D, n_neighbors - 1, axis=1)[:, :n_neighbors]
     indices = indices[sample_range, np.argsort(D[sample_range, indices])]
     distances = D[sample_range, indices]
     return indices, distances
@@ -421,8 +459,7 @@ def _get_indices_distances_from_dense_matrix(D, n_neighbors: int):
 
 def _backwards_compat_get_full_X_diffmap(adata: AnnData) -> np.ndarray:
     if 'X_diffmap0' in adata.obs:
-        return np.c_[adata.obs['X_diffmap0'].values[:, None],
-                     adata.obsm['X_diffmap']]
+        return np.c_[adata.obs['X_diffmap0'].values[:, None], adata.obsm['X_diffmap']]
     else:
         return adata.obsm['X_diffmap']
 
@@ -439,7 +476,9 @@ def _make_forest_dict(forest):
     props = ('hyperplanes', 'offsets', 'children', 'indices')
     for prop in props:
         d[prop] = {}
-        sizes = np.fromiter((getattr(tree, prop).shape[0] for tree in forest), dtype=int)
+        sizes = np.fromiter(
+            (getattr(tree, prop).shape[0] for tree in forest), dtype=int
+        )
         d[prop]['start'] = np.zeros_like(sizes)
         if prop == 'offsets':
             dims = sizes.sum()
@@ -450,7 +489,7 @@ def _make_forest_dict(forest):
         start = 0
         for i, size in enumerate(sizes):
             d[prop]['start'][i] = start
-            end = start+size
+            end = start + size
             dat[start:end] = getattr(forest[i], prop)
             start = end
         d[prop]['data'] = dat
@@ -458,8 +497,8 @@ def _make_forest_dict(forest):
 
 
 class OnFlySymMatrix:
-    """Emulate a matrix where elements are calculated on the fly.
-    """
+    """Emulate a matrix where elements are calculated on the fly."""
+
     def __init__(
         self,
         get_row: Callable[[Any], np.ndarray],
@@ -501,13 +540,15 @@ class OnFlySymMatrix:
             return self.rows[glob_index_0][glob_index_1]
 
     def restrict(self, index_array):
-        """Generate a view restricted to a subset of indices.
-        """
+        """Generate a view restricted to a subset of indices."""
         new_shape = index_array.shape[0], index_array.shape[0]
         return OnFlySymMatrix(
-            self.get_row, new_shape, DC_start=self.DC_start,
+            self.get_row,
+            new_shape,
+            DC_start=self.DC_start,
             DC_end=self.DC_end,
-            rows=self.rows, restrict_array=index_array,
+            rows=self.rows,
+            restrict_array=index_array,
         )
 
 
@@ -528,7 +569,12 @@ class Neighbors:
         Where to look in .uns and .obsp for neighbors data
     """
 
-    def __init__(self, adata: AnnData, n_dcs: Optional[int] = None, neighbors_key: Optional[str] = None):
+    def __init__(
+        self,
+        adata: AnnData,
+        n_dcs: Optional[int] = None,
+        neighbors_key: Optional[str] = None,
+    ):
         self._adata = adata
         self._init_iroot()
         # use the graph in adata
@@ -554,17 +600,26 @@ class Neighbors:
             if 'params' in neighbors:
                 self.n_neighbors = neighbors['params']['n_neighbors']
             else:
+
                 def count_nonzero(a: Union[np.ndarray, csr_matrix]) -> int:
                     return a.count_nonzero() if issparse(a) else np.count_nonzero(a)
+
                 # estimating n_neighbors
                 if self._connectivities is None:
-                    self.n_neighbors = int(count_nonzero(self._distances) / self._distances.shape[0])
+                    self.n_neighbors = int(
+                        count_nonzero(self._distances) / self._distances.shape[0]
+                    )
                 else:
-                    self.n_neighbors = int(count_nonzero(self._connectivities) / self._connectivities.shape[0] / 2)
+                    self.n_neighbors = int(
+                        count_nonzero(self._connectivities)
+                        / self._connectivities.shape[0]
+                        / 2
+                    )
             info_str += '`.distances` `.connectivities` '
             self._number_connected_components = 1
             if issparse(self._connectivities):
                 from scipy.sparse.csgraph import connected_components
+
                 self._connected_components = connected_components(self._connectivities)
                 self._number_connected_components = self._connected_components[0]
         if 'X_diffmap' in adata.obsm_keys():
@@ -574,8 +629,10 @@ class Neighbors:
                 if n_dcs > len(self._eigen_values):
                     raise ValueError(
                         'Cannot instantiate using `n_dcs`={}. '
-                        'Compute diffmap/spectrum with more components first.'
-                        .format(n_dcs))
+                        'Compute diffmap/spectrum with more components first.'.format(
+                            n_dcs
+                        )
+                    )
                 self._eigen_values = self._eigen_values[:n_dcs]
                 self._eigen_basis = self._eigen_basis[:, :n_dcs]
             self.n_dcs = len(self._eigen_values)
@@ -593,14 +650,12 @@ class Neighbors:
 
     @property
     def distances(self) -> Union[np.ndarray, csr_matrix, None]:
-        """Distances between data points (sparse matrix).
-        """
+        """Distances between data points (sparse matrix)."""
         return self._distances
 
     @property
     def connectivities(self) -> Union[np.ndarray, csr_matrix, None]:
-        """Connectivities between data points (sparse matrix).
-        """
+        """Connectivities between data points (sparse matrix)."""
         return self._connectivities
 
     @property
@@ -621,7 +676,7 @@ class Neighbors:
         if issparse(self.Z):
             Zinv = self.Z.power(-1)
         else:
-            Zinv = np.diag(1./np.diag(self.Z))
+            Zinv = np.diag(1.0 / np.diag(self.Z))
         return self.Z @ self.transitions_sym @ Zinv
 
     @property
@@ -639,14 +694,12 @@ class Neighbors:
 
     @property
     def eigen_values(self):
-        """Eigen values of transition matrix (numpy array).
-        """
+        """Eigen values of transition matrix (numpy array)."""
         return self._eigen_values
 
     @property
     def eigen_basis(self):
-        """Eigen basis of transition matrix (numpy array).
-        """
+        """Eigen basis of transition matrix (numpy array)."""
         return self._eigen_basis
 
     @property
@@ -660,8 +713,7 @@ class Neighbors:
         return OnFlySymMatrix(self._get_dpt_row, shape=self._adata.shape)
 
     def to_igraph(self):
-        """Generate igraph from connectiviies.
-        """
+        """Generate igraph from connectiviies."""
         return _utils.get_igraph_from_adjacency(self.connectivities)
 
     @_doc_params(n_pcs=doc_n_pcs, use_rep=doc_use_rep)
@@ -696,14 +748,17 @@ class Neighbors:
         `write_knn_indices==True`.
         """
         from sklearn.metrics import pairwise_distances
+
         start_neighbors = logg.debug('computing neighbors')
         if n_neighbors > self._adata.shape[0]:  # very small datasets
-            n_neighbors = 1 + int(0.5*self._adata.shape[0])
+            n_neighbors = 1 + int(0.5 * self._adata.shape[0])
             logg.warning(f'n_obs too small: adjusting to `n_neighbors = {n_neighbors}`')
         if method == 'umap' and not knn:
             raise ValueError('`method = \'umap\' only with `knn = True`.')
         if method == 'rapids' and metric != 'euclidean':
-            raise ValueError("`method` 'rapids' only supports the 'euclidean' `metric`.")
+            raise ValueError(
+                "`method` 'rapids' only supports the 'euclidean' `metric`."
+            )
         if method not in {'umap', 'gauss', 'rapids'}:
             raise ValueError("`method` needs to be 'umap', 'gauss', or 'rapids'.")
         if self._adata.shape[0] >= 10000 and not knn:
@@ -714,14 +769,16 @@ class Neighbors:
         self.knn = knn
         X = _choose_representation(self._adata, use_rep=use_rep, n_pcs=n_pcs)
         # neighbor search
-        use_dense_distances = (metric == 'euclidean' and X.shape[0] < 8192) or knn == False
+        use_dense_distances = (metric == 'euclidean' and X.shape[0] < 8192) or not knn
         if use_dense_distances:
             _distances = pairwise_distances(X, metric=metric, **metric_kwds)
             knn_indices, knn_distances = _get_indices_distances_from_dense_matrix(
-                _distances, n_neighbors)
+                _distances, n_neighbors
+            )
             if knn:
                 self._distances = _get_sparse_matrix_from_indices_distances_numpy(
-                    knn_indices, knn_distances, X.shape[0], n_neighbors)
+                    knn_indices, knn_distances, X.shape[0], n_neighbors
+                )
             else:
                 self._distances = _distances
         elif method == 'rapids':
@@ -732,12 +789,13 @@ class Neighbors:
                 X = pairwise_distances(X, metric=metric, **metric_kwds)
                 metric = 'precomputed'
             knn_indices, knn_distances, forest = compute_neighbors_umap(
-                X, n_neighbors, random_state, metric=metric, metric_kwds=metric_kwds)
+                X, n_neighbors, random_state, metric=metric, metric_kwds=metric_kwds
+            )
             # very cautious here
             try:
                 if forest:
                     self._rp_forest = _make_forest_dict(forest)
-            except:
+            except Exception:  # TODO catch the correct exception
                 pass
         # write indices as attributes
         if write_knn_indices:
@@ -761,6 +819,7 @@ class Neighbors:
         self._number_connected_components = 1
         if issparse(self._connectivities):
             from scipy.sparse.csgraph import connected_components
+
             self._connected_components = connected_components(self._connectivities)
             self._number_connected_components = self._connected_components[0]
 
@@ -769,11 +828,13 @@ class Neighbors:
         if self.knn:
             Dsq = self._distances.power(2)
             indices, distances_sq = _get_indices_distances_from_sparse_matrix(
-                Dsq, self.n_neighbors)
+                Dsq, self.n_neighbors
+            )
         else:
             Dsq = np.power(self._distances, 2)
             indices, distances_sq = _get_indices_distances_from_dense_matrix(
-                Dsq, self.n_neighbors)
+                Dsq, self.n_neighbors
+            )
 
         # exclude the first point, the 0th neighbor
         indices = indices[:, 1:]
@@ -788,18 +849,18 @@ class Neighbors:
         else:
             # the last item is already in its sorted position through argpartition
             # we have decay beyond the n_neighbors neighbors
-            sigmas_sq = distances_sq[:, -1]/4
+            sigmas_sq = distances_sq[:, -1] / 4
         sigmas = np.sqrt(sigmas_sq)
 
         # compute the symmetric weight matrix
         if not issparse(self._distances):
             Num = 2 * np.multiply.outer(sigmas, sigmas)
             Den = np.add.outer(sigmas_sq, sigmas_sq)
-            W = np.sqrt(Num/Den) * np.exp(-Dsq/Den)
+            W = np.sqrt(Num / Den) * np.exp(-Dsq / Den)
             # make the weight matrix sparse
             if not self.knn:
                 mask = W > 1e-14
-                W[mask == False] = 0
+                W[~mask] = 0
             else:
                 # restrict number of neighbors to ~k
                 # build a symmetric mask
@@ -811,15 +872,18 @@ class Neighbors:
                             W[j, i] = W[i, j]
                             mask[j, i] = True
                 # set all entries that are not nearest neighbors to zero
-                W[mask == False] = 0
+                W[~mask] = 0
         else:
-            W = Dsq.copy()  # need to copy the distance matrix here; what follows is inplace
+            W = (
+                Dsq.copy()
+            )  # need to copy the distance matrix here; what follows is inplace
             for i in range(len(Dsq.indptr[:-1])):
-                row = Dsq.indices[Dsq.indptr[i]:Dsq.indptr[i+1]]
+                row = Dsq.indices[Dsq.indptr[i] : Dsq.indptr[i + 1]]
                 num = 2 * sigmas[i] * sigmas[row]
                 den = sigmas_sq[i] + sigmas_sq[row]
-                W.data[Dsq.indptr[i]:Dsq.indptr[i+1]] = np.sqrt(num/den) * np.exp(
-                    -Dsq.data[Dsq.indptr[i]: Dsq.indptr[i+1]] / den)
+                W.data[Dsq.indptr[i] : Dsq.indptr[i + 1]] = np.sqrt(num / den) * np.exp(
+                    -Dsq.data[Dsq.indptr[i] : Dsq.indptr[i + 1]] / den
+                )
             W = W.tolil()
             for i, row in enumerate(indices):
                 for j in row:
@@ -852,9 +916,9 @@ class Neighbors:
             # it's also the degree of the underlying graph
             q = np.asarray(W.sum(axis=0))
             if not issparse(W):
-                Q = np.diag(1.0/q)
+                Q = np.diag(1.0 / q)
             else:
-                Q = scipy.sparse.spdiags(1.0/q, 0, W.shape[0], W.shape[0])
+                Q = scipy.sparse.spdiags(1.0 / q, 0, W.shape[0], W.shape[0])
             K = Q @ W @ Q
         else:
             K = W
@@ -862,9 +926,9 @@ class Neighbors:
         # z[i] is the square root of the row sum of K
         z = np.sqrt(np.asarray(K.sum(axis=0)))
         if not issparse(K):
-            self.Z = np.diag(1.0/z)
+            self.Z = np.diag(1.0 / z)
         else:
-            self.Z = scipy.sparse.spdiags(1.0/z, 0, K.shape[0], K.shape[0])
+            self.Z = scipy.sparse.spdiags(1.0 / z, 0, K.shape[0], K.shape[0])
         self._transitions_sym = self.Z @ K @ self.Z
         logg.info('    finished', time=start)
 
@@ -908,7 +972,7 @@ class Neighbors:
         if n_comps == 0:
             evals, evecs = scipy.linalg.eigh(matrix)
         else:
-            n_comps = min(matrix.shape[0]-1, n_comps)
+            n_comps = min(matrix.shape[0] - 1, n_comps)
             # ncv = max(2 * n_comps + 1, int(np.sqrt(matrix.shape[0])))
             ncv = None
             which = 'LM' if sort == 'decrease' else 'SM'
@@ -925,7 +989,7 @@ class Neighbors:
             '    eigenvalues of transition matrix\n'
             '    {}'.format(str(evals).replace('\n', '\n    '))
         )
-        if self._number_connected_components > len(evals)/2:
+        if self._number_connected_components > len(evals) / 2:
             logg.warning('Transition matrix has many disconnected components!')
         self._eigen_values = evals
         self._eigen_basis = evecs
@@ -944,8 +1008,10 @@ class Neighbors:
             return
         # set iroot via xroot
         xroot = None
-        if 'xroot' in self._adata.uns: xroot = self._adata.uns['xroot']
-        elif 'xroot' in self._adata.var: xroot = self._adata.var['xroot']
+        if 'xroot' in self._adata.uns:
+            xroot = self._adata.uns['xroot']
+        elif 'xroot' in self._adata.var:
+            xroot = self._adata.var['xroot']
         # see whether we can set self.iroot using the full data matrix
         if xroot is not None and xroot.size == self._adata.shape[1]:
             self._set_iroot_via_xroot(xroot)
@@ -957,12 +1023,14 @@ class Neighbors:
             mask = self._connected_components[1] == label
         row = sum(
             (
-                self.eigen_values[l] / (1-self.eigen_values[l])
-                * (self.eigen_basis[i, l] - self.eigen_basis[:, l])
-            )**2
+                self.eigen_values[j]
+                / (1 - self.eigen_values[j])
+                * (self.eigen_basis[i, j] - self.eigen_basis[:, j])
+            )
+            ** 2
             # account for float32 precision
-            for l in range(0, self.eigen_values.size)
-            if self.eigen_values[l] < 0.9994
+            for j in range(0, self.eigen_values.size)
+            if self.eigen_values[j] < 0.9994
         )
         # thanks to Marius Lange for pointing Alex to this:
         # we will likely remove the contributions from the stationary state below when making
@@ -970,17 +1038,16 @@ class Neighbors:
         # they never seem to have deteriorated results, but also other distance measures (see e.g.
         # PAGA paper) don't have it, which makes sense
         row += sum(
-            (self.eigen_basis[i, l] - self.eigen_basis[:, l])**2
-            for l in range(0, self.eigen_values.size)
-            if self.eigen_values[l] >= 0.9994
+            (self.eigen_basis[i, k] - self.eigen_basis[:, k]) ** 2
+            for k in range(0, self.eigen_values.size)
+            if self.eigen_values[k] >= 0.9994
         )
         if mask is not None:
             row[~mask] = np.inf
         return np.sqrt(row)
 
     def _set_pseudotime(self):
-        """Return pseudotime with respect to root point.
-        """
+        """Return pseudotime with respect to root point."""
         self.pseudotime = self.distances_dpt[self.iroot].copy()
         self.pseudotime /= np.max(self.pseudotime[self.pseudotime < np.inf])
 
@@ -998,8 +1065,8 @@ class Neighbors:
         """
         if self._adata.shape[1] != xroot.size:
             raise ValueError(
-                'The root vector you provided does not have the '
-                'correct dimension.')
+                'The root vector you provided does not have the ' 'correct dimension.'
+            )
         # this is the squared distance
         dsqroot = 1e10
         iroot = 0
@@ -1009,7 +1076,8 @@ class Neighbors:
             if dsq < dsqroot:
                 dsqroot = dsq
                 iroot = i
-                if np.sqrt(dsqroot) < 1e-10: break
+                if np.sqrt(dsqroot) < 1e-10:
+                    break
         logg.debug(f'setting root index to {iroot}')
         if self.iroot is not None and iroot != self.iroot:
             logg.warning(f'Changing index of iroot from {self.iroot} to {iroot}.')
