@@ -552,7 +552,7 @@ def ranking(
         n_rows, n_cols = 1, n_panels
     else:
         n_rows, n_cols = 2, int(n_panels / 2 + 0.5)
-    fig = pl.figure(
+    _ = pl.figure(
         figsize=(
             n_cols * rcParams['figure.figsize'][0],
             n_rows * rcParams['figure.figsize'][1],
@@ -1474,7 +1474,7 @@ def tracksplot(
         ymin, ymax = ax.get_ylim()
         ymax = int(ymax)
         ax.set_yticks([ymax])
-        tt = ax.set_yticklabels([str(ymax)], ha='left', va='top')
+        ax.set_yticklabels([str(ymax)], ha='left', va='top')
         ax.spines['right'].set_position(('axes', 1.01))
         ax.tick_params(
             axis='y',
@@ -1710,14 +1710,14 @@ def correlation_matrix(
         )
         axs.append(dendro_ax)
     # define some default pcolormesh parameters
-    if 'edge_color' not in kwds:
+    if 'edgecolors' not in kwds:
         if corr_matrix.shape[0] > 30:
             # when there are too many rows it is better to remove
             # the black lines surrounding the boxes in the heatmap
             kwds['edgecolors'] = 'none'
         else:
             kwds['edgecolors'] = 'black'
-            kwds['linewidth'] = 0.01
+            kwds.setdefault('linewidth', 0.01)
     if 'vmax' not in kwds and 'vmin' not in kwds:
         kwds['vmax'] = 1
         kwds['vmin'] = -1
@@ -1866,6 +1866,18 @@ def _prepare_dataframe(
         categorical = obs_tidy[groupby].agg('_'.join, axis=1).astype('category')
         categorical.name = "_".join(groupby)
 
+        # preserve category order
+        from itertools import product
+
+        order = {
+            "_".join(k): idx
+            for idx, k in enumerate(
+                product(*(obs_tidy[g].cat.categories for g in groupby))
+            )
+        }
+        categorical = categorical.cat.reorder_categories(
+            sorted(categorical.cat.categories, key=lambda x: order[x])
+        )
     obs_tidy = obs_tidy[var_names].set_index(categorical)
     categories = obs_tidy.index.categories
 
@@ -1960,7 +1972,7 @@ def _plot_gene_groups_brackets(
                     va='bottom',
                     rotation=rotation,
                 )
-            except:
+            except Exception:  # TODO catch the correct exception
                 pass
     else:
         top = left
