@@ -55,7 +55,7 @@ def pca_overview(adata: AnnData, **params):
     show = params['show'] if 'show' in params else None
     if 'show' in params:
         del params['show']
-    scatterplots.pca(adata, **params, show=False)
+    pca(adata, **params, show=False)
     pca_loadings(adata, show=False)
     pca_variance_ratio(adata, show=show)
 
@@ -99,7 +99,11 @@ def pca_loadings(
         logg.error("Component indices must be greater than zero.")
         return
     ranking(
-        adata, 'varm', 'PCs', indices=components, include_lowest=include_lowest,
+        adata,
+        'varm',
+        'PCs',
+        indices=components,
+        include_lowest=include_lowest,
     )
     savefig_or_show('pca_loadings', show=show, save=save)
 
@@ -346,15 +350,15 @@ def rank_genes_groups(
 
 def _fig_show_save_or_axes(plot_obj, return_fig, show, save):
     """
-     Decides what to return
-     """
+    Decides what to return
+    """
     if return_fig:
         return plot_obj
     else:
         plot_obj.make_figure()
         savefig_or_show(plot_obj.DEFAULT_SAVE_PREFIX, show=show, save=save)
         show = settings.autoshow if show is None else show
-        if not show:
+        if show is False:
             return plot_obj.get_axes()
 
 
@@ -956,7 +960,7 @@ def rank_genes_groups_violin(
         )
         savefig_or_show(writekey, show=show, save=save)
         axs.append(_ax)
-    if show == False:
+    if show is False:
         return axs
 
 
