@@ -220,7 +220,6 @@ def embedding(
     else:
         size = 120000 / adata.shape[0]
 
-    ###
     # make the plots
     axs = []
     import itertools
@@ -252,7 +251,7 @@ def embedding(
             na_color=na_color,
         )
 
-        ### Order points
+        # Order points
         order = slice(None)
         if sort_order is True and value_to_plot is not None and categorical is False:
             # Higher values plotted on top, null values on bottom
@@ -470,7 +469,6 @@ def _get_vmin_vmax(
     index: int,
     color_vector: Sequence[float],
 ) -> Tuple[Union[float, None], Union[float, None]]:
-
     """
     Evaluates the value of vmin and vmax, which could be a
     str in which case is interpreted as a percentile and should
@@ -730,7 +728,7 @@ def pca(
         )
     else:
 
-        if 'pca' not in adata.obsm.keys() and f"X_pca" not in adata.obsm.keys():
+        if 'pca' not in adata.obsm.keys() and 'X_pca' not in adata.obsm.keys():
             raise KeyError(
                 f"Could not find entry in `obsm` for 'pca'.\n"
                 f"Available keys are: {list(adata.obsm.keys())}."
@@ -977,7 +975,7 @@ def _get_data_points(
             data_points = []
             for comp in components_list:
                 data_points.append(adata.obsm[basis_key][:, comp])
-        except:
+        except Exception:  # TODO catch the correct exception
             raise ValueError(
                 "Given components: '{}' are not valid. Please check. "
                 "A valid example is `components='2,3'`"
