@@ -1,6 +1,5 @@
 import warnings
 from typing import Optional
-
 import numpy as np
 import pandas as pd
 import scipy.sparse as sp_sparse
@@ -21,7 +20,8 @@ def _highly_variable_genes_seurat_v3(
     layer: Optional[str] = None,
     n_top_genes: int = 2000,
     batch_key: Optional[str] = None,
-    span: Optional[float] = 0.3,
+    check_values: bool = True,
+    span: float = 0.3,
     subset: bool = False,
     inplace: bool = True,
 ) -> Optional[pd.DataFrame]:
@@ -55,14 +55,17 @@ def _highly_variable_genes_seurat_v3(
         raise ImportError(
             'Please install skmisc package via `pip install --user scikit-misc'
         )
-
+    df = pd.DataFrame(index=adata.var_names)
     X = adata.layers[layer] if layer is not None else adata.X
-    if check_nonnegative_integers(X) is False:
-        raise ValueError(
-            "`pp.highly_variable_genes` with `flavor='seurat_v3'` expects "
-            "raw count data."
+
+    if check_values and not check_nonnegative_integers(X):
+        warnings.warn(
+            "`flavor='seurat_v3'` expects raw count data, but non-integers were found.",
+            UserWarning,
         )
 
+    df['means'], df['variances'] = _get_mean_var(X)
+
     if batch_key is None:
         batch_info = pd.Categorical(np.zeros(adata.shape[0], dtype=int))
     else:
@@ -70,13 +73,11 @@ def _highly_variable_genes_seurat_v3(
 
     norm_gene_vars = []
     for b in np.unique(batch_info):
+        X_batch = X[batch_info == b]
 
-        ad = adata[batch_info == b]
-        X = ad.layers[layer] if layer is not None else ad.X
-
-        mean, var = _get_mean_var(X)
+        mean, var = _get_mean_var(X_batch)
         not_const = var > 0
-        estimat_var = np.zeros(adata.shape[1], dtype=np.float64)
+        estimat_var = np.zeros(X.shape[1], dtype=np.float64)
 
         y = np.log10(var[not_const])
         x = np.log10(mean[not_const])
@@ -85,25 +86,26 @@ def _highly_variable_genes_seurat_v3(
         estimat_var[not_const] = model.outputs.fitted_values
         reg_std = np.sqrt(10 ** estimat_var)
 
-        batch_counts = X.astype(np.float64).copy()
+        batch_counts = X_batch.astype(np.float64).copy()
         # clip large values as in Seurat
-        N = np.sum(batch_info == b)
+        N = X_batch.shape[0]
         vmax = np.sqrt(N)
         clip_val = reg_std * vmax + mean
         if sp_sparse.issparse(batch_counts):
             batch_counts = sp_sparse.csr_matrix(batch_counts)
             mask = batch_counts.data > clip_val[batch_counts.indices]
             batch_counts.data[mask] = clip_val[batch_counts.indices[mask]]
-        else:
-            clip_val_broad = np.broadcast_to(clip_val, batch_counts.shape)
-            np.putmask(
-                batch_counts, batch_counts > clip_val_broad, clip_val_broad,
-            )
 
-        if sp_sparse.issparse(batch_counts):
             squared_batch_counts_sum = np.array(batch_counts.power(2).sum(axis=0))
             batch_counts_sum = np.array(batch_counts.sum(axis=0))
         else:
+            clip_val_broad = np.broadcast_to(clip_val, batch_counts.shape)
+            np.putmask(
+                batch_counts,
+                batch_counts > clip_val_broad,
+                clip_val_broad,
+            )
+
             squared_batch_counts_sum = np.square(batch_counts).sum(axis=0)
             batch_counts_sum = batch_counts.sum(axis=0)
 
@@ -127,22 +129,21 @@ def _highly_variable_genes_seurat_v3(
     ma_ranked = np.ma.masked_invalid(ranked_norm_gene_vars)
     median_ranked = np.ma.median(ma_ranked, axis=0).filled(np.nan)
 
-    df = pd.DataFrame(index=np.array(adata.var_names))
     df['highly_variable_nbatches'] = num_batches_high_var
     df['highly_variable_rank'] = median_ranked
     df['variances_norm'] = np.mean(norm_gene_vars, axis=0)
-    df['means'] = mean
-    df['variances'] = var
 
-    df.sort_values(
-        ['highly_variable_rank', 'highly_variable_nbatches'],
-        ascending=[True, False],
-        na_position='last',
-        inplace=True,
+    sorted_index = (
+        df[['highly_variable_rank', 'highly_variable_nbatches']]
+        .sort_values(
+            ['highly_variable_rank', 'highly_variable_nbatches'],
+            ascending=[True, False],
+            na_position='last',
+        )
+        .index
     )
     df['highly_variable'] = False
-    df.loc[: int(n_top_genes), 'highly_variable'] = True
-    df = df.loc[adata.var_names]
+    df.loc[sorted_index[: int(n_top_genes)], 'highly_variable'] = True
 
     if inplace or subset:
         adata.uns['hvg'] = {'flavor': 'seurat_v3'}
@@ -192,7 +193,6 @@ def _highly_variable_genes_single_batch(
     A DataFrame that contains the columns
     `highly_variable`, `means`, `dispersions`, and `dispersions_norm`.
     """
-
     X = adata.layers[layer] if layer is not None else adata.X
     if flavor == 'seurat':
         if 'log1p' in adata.uns_keys() and adata.uns['log1p']['base'] is not None:
@@ -256,14 +256,14 @@ def _highly_variable_genes_single_batch(
             ) / disp_mad_bin[df['mean_bin'].values].values
     else:
         raise ValueError('`flavor` needs to be "seurat" or "cell_ranger"')
-    dispersion_norm = df['dispersions_norm'].values.astype('float32')
+    dispersion_norm = df['dispersions_norm'].values
     if n_top_genes is not None:
         dispersion_norm = dispersion_norm[~np.isnan(dispersion_norm)]
         dispersion_norm[
             ::-1
         ].sort()  # interestingly, np.argpartition is slightly slower
         if n_top_genes > adata.n_vars:
-            logg.info(f'`n_top_genes` > `adata.n_var`, returning all genes.')
+            logg.info('`n_top_genes` > `adata.n_var`, returning all genes.')
             n_top_genes = adata.n_vars
         disp_cut_off = dispersion_norm[n_top_genes - 1]
         gene_subset = np.nan_to_num(df['dispersions_norm'].values) >= disp_cut_off
@@ -300,6 +300,7 @@ def highly_variable_genes(
     subset: bool = False,
     inplace: bool = True,
     batch_key: Optional[str] = None,
+    check_values: bool = True,
 ) -> Optional[pd.DataFrame]:
     """\
     Annotate highly variable genes [Satija15]_ [Zheng17]_ [Stuart19]_.
@@ -366,6 +367,9 @@ def highly_variable_genes(
         by how many batches they are a HVG. For dispersion-based flavors ties are broken
         by normalized dispersion. If `flavor = 'seurat_v3'`, ties are broken by the median
         (across batches) rank based on within-batch normalized variance.
+    check_values
+        Check if counts in selected layer are integers. A Warning is returned if set to True.
+        Only used if `flavor='seurat_v3'`.
 
     Returns
     -------
@@ -417,6 +421,7 @@ def highly_variable_genes(
             layer=layer,
             n_top_genes=n_top_genes,
             batch_key=batch_key,
+            check_values=check_values,
             span=span,
             subset=subset,
             inplace=inplace,
@@ -461,7 +466,8 @@ def highly_variable_genes(
 
             # Add 0 values for genes that were filtered out
             missing_hvg = pd.DataFrame(
-                np.zeros((np.sum(~filt), len(hvg.columns))), columns=hvg.columns,
+                np.zeros((np.sum(~filt), len(hvg.columns))),
+                columns=hvg.columns,
             )
             missing_hvg['highly_variable'] = missing_hvg['highly_variable'].astype(bool)
             missing_hvg['gene'] = gene_list[~filt]
@@ -501,7 +507,7 @@ def highly_variable_genes(
                 inplace=True,
             )
             df['highly_variable'] = False
-            df.loc[:n_top_genes, 'highly_variable'] = True
+            df.highly_variable.iloc[:n_top_genes] = True
             df = df.loc[adata.var_names]
         else:
             df = df.loc[adata.var_names]
