@@ -88,7 +88,7 @@ def describe_obs(
     if parallel is not None:
         warn(
             "Argument `parallel` is deprecated, and currently has no effect.",
-            FutureWarning
+            FutureWarning,
         )
     # Handle whether X is passed
     if X is None:
@@ -108,7 +108,9 @@ def describe_obs(
         )
     obs_metrics[f"total_{expr_type}"] = X.sum(axis=1)
     if log1p:
-        obs_metrics[f"log1p_total_{expr_type}"] = np.log1p(obs_metrics[f"total_{expr_type}"])
+        obs_metrics[f"log1p_total_{expr_type}"] = np.log1p(
+            obs_metrics[f"total_{expr_type}"]
+        )
     if percent_top:
         percent_top = sorted(percent_top)
         proportions = top_segment_proportions(X, percent_top)
@@ -117,8 +119,8 @@ def describe_obs(
                 proportions[:, i] * 100
             )
     for qc_var in qc_vars:
-        obs_metrics[f"total_{expr_type}_{qc_var}"] = (
-            X[:, adata.var[qc_var].values].sum(axis=1)
+        obs_metrics[f"total_{expr_type}_{qc_var}"] = X[:, adata.var[qc_var].values].sum(
+            axis=1
         )
         if log1p:
             obs_metrics[f"log1p_total_{expr_type}_{qc_var}"] = np.log1p(
@@ -191,13 +193,17 @@ def describe_var(
         var_metrics["n_cells_by_{expr_type}"] = np.count_nonzero(X, axis=0)
         var_metrics["mean_{expr_type}"] = X.mean(axis=0)
     if log1p:
-        var_metrics["log1p_mean_{expr_type}"] = np.log1p(var_metrics["mean_{expr_type}"])
+        var_metrics["log1p_mean_{expr_type}"] = np.log1p(
+            var_metrics["mean_{expr_type}"]
+        )
     var_metrics["pct_dropout_by_{expr_type}"] = (
         1 - var_metrics["n_cells_by_{expr_type}"] / X.shape[0]
     ) * 100
     var_metrics["total_{expr_type}"] = np.ravel(X.sum(axis=0))
     if log1p:
-        var_metrics["log1p_total_{expr_type}"] = np.log1p(var_metrics["total_{expr_type}"])
+        var_metrics["log1p_total_{expr_type}"] = np.log1p(
+            var_metrics["total_{expr_type}"]
+        )
     # Relabel
     new_colnames = []
     for col in var_metrics.columns:
@@ -276,7 +282,7 @@ def calculate_qc_metrics(
     if parallel is not None:
         warn(
             "Argument `parallel` is deprecated, and currently has no effect.",
-            FutureWarning
+            FutureWarning,
         )
     # Pass X so I only have to do it once
     X = _choose_mtx_rep(adata, use_raw, layer)
@@ -296,7 +302,12 @@ def calculate_qc_metrics(
         log1p=log1p,
     )
     var_metrics = describe_var(
-        adata, expr_type=expr_type, var_type=var_type, inplace=inplace, X=X, log1p=log1p,
+        adata,
+        expr_type=expr_type,
+        var_type=var_type,
+        inplace=inplace,
+        X=X,
+        log1p=log1p,
     )
 
     if not inplace:
@@ -344,7 +355,7 @@ def top_proportions_sparse_csr(data, indptr, n):
         start, end = indptr[i], indptr[i + 1]
         vec = np.zeros(n, dtype=np.float64)
         if end - start <= n:
-            vec[:end - start] = data[start:end]
+            vec[: end - start] = data[start:end]
             total = vec.sum()
         else:
             vec[:] = -(np.partition(-data[start:end], n - 1)[:n])
@@ -375,9 +386,7 @@ def top_segment_proportions(
     if issparse(mtx):
         if not isspmatrix_csr(mtx):
             mtx = csr_matrix(mtx)
-        return top_segment_proportions_sparse_csr(
-            mtx.data, mtx.indptr, np.array(ns)
-        )
+        return top_segment_proportions_sparse_csr(mtx.data, mtx.indptr, np.array(ns))
     else:
         return top_segment_proportions_dense(mtx, ns)
 
@@ -388,7 +397,9 @@ def top_segment_proportions_dense(
     # Currently ns is considered to be 1 indexed
     ns = np.sort(ns)
     sums = mtx.sum(axis=1)
-    partitioned = np.apply_along_axis(np.partition, 1, mtx, mtx.shape[1] - ns)[:, ::-1][:, :ns[-1]]
+    partitioned = np.apply_along_axis(np.partition, 1, mtx, mtx.shape[1] - ns)[:, ::-1][
+        :, : ns[-1]
+    ]
     values = np.zeros((mtx.shape[0], len(ns)))
     acc = np.zeros(mtx.shape[0])
     prev = 0
@@ -418,12 +429,12 @@ def top_segment_proportions_sparse_csr(data, indptr, ns):
         elif (end - start) > maxidx:
             partitioned[i, :] = -(np.partition(-data[start:end], maxidx))[:maxidx]
         partitioned[i, :] = np.partition(partitioned[i, :], maxidx - ns)
-    partitioned = partitioned[:, ::-1][:, :ns[-1]]
+    partitioned = partitioned[:, ::-1][:, : ns[-1]]
     acc = np.zeros((indptr.size - 1), dtype=data.dtype)
     prev = 0
     # can’t use enumerate due to https://github.com/numba/numba/issues/2625
     for j in range(ns.size):
-        acc += partitioned[:, prev:ns[j]].sum(axis=1)
+        acc += partitioned[:, prev : ns[j]].sum(axis=1)
         values[:, j] = acc
         prev = ns[j]
     return values / sums.reshape((indptr.size - 1, 1))
