@@ -16,6 +16,7 @@ import numpy as np
 import pytest
 
 from matplotlib.testing import setup
+
 setup()
 
 import scanpy as sc
@@ -29,7 +30,9 @@ FIGS = HERE / 'figures'
 def test_pbmc3k(image_comparer):
     save_and_compare_images = image_comparer(ROOT, FIGS, tol=20)
 
-    adata = sc.read('./data/pbmc3k_raw.h5ad', backup_url='http://falexwolf.de/data/pbmc3k_raw.h5ad')
+    adata = sc.read(
+        './data/pbmc3k_raw.h5ad', backup_url='http://falexwolf.de/data/pbmc3k_raw.h5ad'
+    )
 
     # Preprocessing
 
@@ -43,15 +46,17 @@ def test_pbmc3k(image_comparer):
     # for each cell compute fraction of counts in mito genes vs. all genes
     # the `.A1` is only necessary as X is sparse to transform to a dense array after summing
     adata.obs['percent_mito'] = (
-        np.sum(adata[:, mito_genes].X, axis=1).A1 /
-        np.sum(adata.X, axis=1).A1
+        np.sum(adata[:, mito_genes].X, axis=1).A1 / np.sum(adata.X, axis=1).A1
     )
     # add the total counts per cell as observations-annotation to adata
     adata.obs['n_counts'] = adata.X.sum(axis=1).A1
 
     sc.pl.violin(
-        adata, ['n_genes', 'n_counts', 'percent_mito'],
-        jitter=False, multi_panel=True, show=False,
+        adata,
+        ['n_genes', 'n_counts', 'percent_mito'],
+        jitter=False,
+        multi_panel=True,
+        show=False,
     )
     save_and_compare_images('violin')
 
@@ -68,7 +73,10 @@ def test_pbmc3k(image_comparer):
     sc.pp.normalize_per_cell(adata, counts_per_cell_after=1e4)
 
     filter_result = sc.pp.filter_genes_dispersion(
-        adata.X, min_mean=0.0125, max_mean=3, min_disp=0.5,
+        adata.X,
+        min_mean=0.0125,
+        max_mean=3,
+        min_disp=0.5,
     )
     sc.pl.filter_genes_dispersion(filter_result, show=False)
     save_and_compare_images('filter_genes_dispersion')
@@ -122,15 +130,21 @@ def test_pbmc3k(image_comparer):
     # save_and_compare_images('rank_genes_groups_4')
 
     new_cluster_names = [
-        'CD4 T cells', 'CD14+ Monocytes',
-        'B cells', 'CD8 T cells',
-        'NK cells', 'FCGR3A+ Monocytes',
-        'Dendritic cells', 'Megakaryocytes',
+        'CD4 T cells',
+        'CD14+ Monocytes',
+        'B cells',
+        'CD8 T cells',
+        'NK cells',
+        'FCGR3A+ Monocytes',
+        'Dendritic cells',
+        'Megakaryocytes',
     ]
     adata.rename_categories('louvain', new_cluster_names)
 
     # sc.pl.umap(adata, color='louvain', legend_loc='on data', title='', frameon=False, show=False)
     # save_and_compare_images('umap_3')
 
-    sc.pl.violin(adata, ['CST3', 'NKG7', 'PPBP'], groupby='louvain', rotation=90, show=False)
+    sc.pl.violin(
+        adata, ['CST3', 'NKG7', 'PPBP'], groupby='louvain', rotation=90, show=False
+    )
     save_and_compare_images('violin_2')
