@@ -1,5 +1,6 @@
 from functools import partial
 from pathlib import Path
+import sys
 from itertools import repeat, chain, combinations
 
 import pytest
@@ -435,7 +436,7 @@ def test_multiple_plots(image_comparer):
     fig, (ax1, ax2, ax3) = plt.subplots(
         1, 3, figsize=(20, 5), gridspec_kw={'wspace': 0.7}
     )
-    __ = sc.pl.stacked_violin(
+    _ = sc.pl.stacked_violin(
         adata,
         markers,
         groupby='bulk_labels',
@@ -444,7 +445,7 @@ def test_multiple_plots(image_comparer):
         dendrogram=True,
         show=False,
     )
-    __ = sc.pl.dotplot(
+    _ = sc.pl.dotplot(
         adata,
         markers,
         groupby='bulk_labels',
@@ -453,7 +454,7 @@ def test_multiple_plots(image_comparer):
         dendrogram=True,
         show=False,
     )
-    __ = sc.pl.matrixplot(
+    _ = sc.pl.matrixplot(
         adata,
         markers,
         groupby='bulk_labels',
@@ -542,6 +543,10 @@ def test_dendrogram(image_comparer):
     save_and_compare_images('dendrogram')
 
 
+# See https://github.com/theislab/scanpy/pull/1768
+@pytest.mark.skipif(
+    sys.version_info < (3, 7), reason="matplotlib 3.4 dropped support for python 3.6"
+)
 def test_correlation(image_comparer):
     save_and_compare_images = image_comparer(ROOT, FIGS, tol=15)
 
@@ -1048,3 +1053,23 @@ def test_groupby_index(image_comparer):
     pbmc_subset = pbmc[:10].copy()
     sc.pl.dotplot(pbmc_subset, genes, groupby='index')
     save_and_compare_images('master_dotplot_groupby_index')
+
+
+# test category order when groupby is a list (#1735)
+def test_groupby_list(image_comparer):
+    save_and_compare_images = image_comparer(ROOT, FIGS, tol=30)
+    adata = sc.datasets.krumsiek11()
+
+    np.random.seed(1)
+
+    cat_val = adata.obs.cell_type.tolist()
+    np.random.shuffle(cat_val)
+    cats = adata.obs.cell_type.cat.categories.tolist()
+    np.random.shuffle(cats)
+    adata.obs['rand_cat'] = pd.Categorical(cat_val, categories=cats)
+
+    with mpl.rc_context({"figure.subplot.bottom": 0.5}):
+        sc.pl.dotplot(
+            adata, ['Gata1', 'Gata2'], groupby=['rand_cat', 'cell_type'], swap_axes=True
+        )
+        save_and_compare_images('master_dotplot_groupby_list_catorder')
