@@ -30,7 +30,7 @@ def test_log1p(tmp_path):
     # Test base
     ad4 = AnnData(A)
     sc.pp.log1p(ad4, base=2)
-    assert np.allclose(ad4.X, A_l/np.log(2))
+    assert np.allclose(ad4.X, A_l / np.log(2))
 
 
 @pytest.fixture(params=[None, 2])
@@ -38,8 +38,10 @@ def base(request):
     return request.param
 
 
-def test_log1p_rep(count_matrix_format, base):
-    X = count_matrix_format(sp.random(100, 200, density=0.3).toarray())
+def test_log1p_rep(count_matrix_format, base, dtype):
+    X = count_matrix_format(
+        np.abs(sp.random(100, 200, density=0.3, dtype=dtype)).toarray()
+    )
     check_rep_mutation(sc.pp.log1p, X, base=base)
     check_rep_results(sc.pp.log1p, X, base=base)
 
@@ -54,7 +56,7 @@ def test_mean_var_sparse():
     for mtx, ax in product((csr64, csc64), (0, 1)):
         scm, scv = sc.pp._utils._get_mean_var(mtx, axis=ax)
         skm, skv = mean_variance_axis(mtx, ax)
-        skv *= (mtx.shape[ax] / (mtx.shape[ax] - 1))
+        skv *= mtx.shape[ax] / (mtx.shape[ax] - 1)
 
         assert np.allclose(scm, skm)
         assert np.allclose(scv, skv)
@@ -68,8 +70,8 @@ def test_mean_var_sparse():
         scm64, scv64 = sc.pp._utils._get_mean_var(mtx64)
         skm32, skv32 = mean_variance_axis(mtx32, 0)
         skm64, skv64 = mean_variance_axis(mtx64, 0)
-        skv32 *= (mtx.shape[0] / (mtx.shape[0] - 1))
-        skv64 *= (mtx.shape[0] / (mtx.shape[0] - 1))
+        skv32 *= mtx.shape[0] / (mtx.shape[0] - 1)
+        skv64 *= mtx.shape[0] / (mtx.shape[0] - 1)
 
         m_resid_sc = np.mean(np.abs(scm64 - scm32))
         m_resid_sk = np.mean(np.abs(skm64 - skm32))
@@ -81,28 +83,21 @@ def test_mean_var_sparse():
 
 
 def test_normalize_per_cell():
-    adata = AnnData(
-        np.array([[1, 0], [3, 0], [5, 6]]))
-    sc.pp.normalize_per_cell(adata, counts_per_cell_after=1,
-                             key_n_counts='n_counts2')
-    assert adata.X.sum(axis=1).tolist() == [1., 1., 1.]
+    adata = AnnData(np.array([[1, 0], [3, 0], [5, 6]]))
+    sc.pp.normalize_per_cell(adata, counts_per_cell_after=1, key_n_counts='n_counts2')
+    assert adata.X.sum(axis=1).tolist() == [1.0, 1.0, 1.0]
     # now with copy option
-    adata = AnnData(
-        np.array([[1, 0], [3, 0], [5, 6]]))
+    adata = AnnData(np.array([[1, 0], [3, 0], [5, 6]]))
     # note that sc.pp.normalize_per_cell is also used in
     # pl.highest_expr_genes with parameter counts_per_cell_after=100
-    adata_copy = sc.pp.normalize_per_cell(
-        adata, counts_per_cell_after=1, copy=True)
-    assert adata_copy.X.sum(axis=1).tolist() == [1., 1., 1.]
+    adata_copy = sc.pp.normalize_per_cell(adata, counts_per_cell_after=1, copy=True)
+    assert adata_copy.X.sum(axis=1).tolist() == [1.0, 1.0, 1.0]
     # now sparse
-    adata = AnnData(
-        np.array([[1, 0], [3, 0], [5, 6]]))
-    adata_sparse = AnnData(
-        sp.csr_matrix([[1, 0], [3, 0], [5, 6]]))
+    adata = AnnData(np.array([[1, 0], [3, 0], [5, 6]]))
+    adata_sparse = AnnData(sp.csr_matrix([[1, 0], [3, 0], [5, 6]]))
     sc.pp.normalize_per_cell(adata)
     sc.pp.normalize_per_cell(adata_sparse)
-    assert adata.X.sum(axis=1).tolist() == adata_sparse.X.sum(
-        axis=1).A1.tolist()
+    assert adata.X.sum(axis=1).tolist() == adata_sparse.X.sum(axis=1).A1.tolist()
 
 
 def test_subsample():
@@ -122,7 +117,7 @@ def test_subsample_copy():
 def test_scale():
     adata = sc.datasets.pbmc68k_reduced()
     adata.X = adata.raw.X
-    v = adata[:, 0:adata.shape[1] // 2]
+    v = adata[:, 0 : adata.shape[1] // 2]
     # Should turn view to copy https://github.com/theislab/anndata/issues/171#issuecomment-508689965
     assert v.is_view
     with pytest.warns(Warning, match="view"):
@@ -168,24 +163,28 @@ def test_recipe_plotting():
 
 def test_regress_out_ordinal():
     from scipy.sparse import random
+
     adata = AnnData(random(1000, 100, density=0.6, format='csr'))
     adata.obs['percent_mito'] = np.random.rand(adata.X.shape[0])
     adata.obs['n_counts'] = adata.X.sum(axis=1)
 
     # results using only one processor
     single = sc.pp.regress_out(
-        adata, keys=['n_counts', 'percent_mito'], n_jobs=1, copy=True)
+        adata, keys=['n_counts', 'percent_mito'], n_jobs=1, copy=True
+    )
     assert adata.X.shape == single.X.shape
 
     # results using 8 processors
     multi = sc.pp.regress_out(
-        adata, keys=['n_counts', 'percent_mito'], n_jobs=8, copy=True)
+        adata, keys=['n_counts', 'percent_mito'], n_jobs=8, copy=True
+    )
 
     np.testing.assert_array_equal(single.X, multi.X)
 
 
 def test_regress_out_view():
     from scipy.sparse import random
+
     adata = AnnData(random(500, 1100, density=0.2, format='csr'))
     adata.obs['percent_mito'] = np.random.rand(adata.X.shape[0])
     adata.obs['n_counts'] = adata.X.sum(axis=1)
@@ -201,17 +200,17 @@ def test_regress_out_view():
 def test_regress_out_categorical():
     from scipy.sparse import random
     import pandas as pd
+
     adata = AnnData(random(1000, 100, density=0.6, format='csr'))
     # create a categorical column
-    adata.obs['batch'] = pd.Categorical(
-        np.random.randint(1, 4, size=adata.X.shape[0]))
+    adata.obs['batch'] = pd.Categorical(np.random.randint(1, 4, size=adata.X.shape[0]))
 
     multi = sc.pp.regress_out(adata, keys='batch', n_jobs=8, copy=True)
     assert adata.X.shape == multi.X.shape
 
 
 def test_regress_out_constants():
-    adata = AnnData(np.hstack((np.full((10,1),0.0),np.full((10,1),1.0))))
+    adata = AnnData(np.hstack((np.full((10, 1), 0.0), np.full((10, 1), 1.0))))
     adata.obs['percent_mito'] = np.random.rand(adata.X.shape[0])
     adata.obs['n_counts'] = adata.X.sum(axis=1)
     adata_copy = adata.copy()
@@ -244,6 +243,7 @@ def count_matrix_format(request):
 def replace(request):
     return request.param
 
+
 @pytest.fixture(params=[np.int64, np.float32, np.float64])
 def dtype(request):
     return request.param
@@ -251,10 +251,7 @@ def dtype(request):
 
 def test_downsample_counts_per_cell(count_matrix_format, replace, dtype):
     TARGET = 1000
-    X = (
-        np.random.randint(0, 100, (1000, 100))
-        * np.random.binomial(1, 0.3, (1000, 100))
-    )
+    X = np.random.randint(0, 100, (1000, 100)) * np.random.binomial(1, 0.3, (1000, 100))
     X = X.astype(dtype)
     adata = AnnData(X=count_matrix_format(X), dtype=dtype)
     with pytest.raises(ValueError):
@@ -275,8 +272,7 @@ def test_downsample_counts_per_cell(count_matrix_format, replace, dtype):
     assert all(new_totals <= TARGET)
     assert all(initial_totals >= new_totals)
     assert all(
-        initial_totals[initial_totals <= TARGET]
-        == new_totals[initial_totals <= TARGET]
+        initial_totals[initial_totals <= TARGET] == new_totals[initial_totals <= TARGET]
     )
     if not replace:
         assert np.all(X >= adata.X)
@@ -287,17 +283,12 @@ def test_downsample_counts_per_cell_multiple_targets(
     count_matrix_format, replace, dtype
 ):
     TARGETS = np.random.randint(500, 1500, 1000)
-    X = (
-        np.random.randint(0, 100, (1000, 100))
-        * np.random.binomial(1, 0.3, (1000, 100))
-    )
+    X = np.random.randint(0, 100, (1000, 100)) * np.random.binomial(1, 0.3, (1000, 100))
     X = X.astype(dtype)
     adata = AnnData(X=count_matrix_format(X), dtype=dtype)
     initial_totals = np.ravel(adata.X.sum(axis=1))
     with pytest.raises(ValueError):
-        sc.pp.downsample_counts(
-            adata, counts_per_cell=[40, 10], replace=replace
-        )
+        sc.pp.downsample_counts(adata, counts_per_cell=[40, 10], replace=replace)
     adata = sc.pp.downsample_counts(
         adata, counts_per_cell=TARGETS, replace=replace, copy=True
     )
@@ -318,10 +309,7 @@ def test_downsample_counts_per_cell_multiple_targets(
 
 
 def test_downsample_total_counts(count_matrix_format, replace, dtype):
-    X = (
-        np.random.randint(0, 100, (1000, 100))
-        * np.random.binomial(1, 0.3, (1000, 100))
-    )
+    X = np.random.randint(0, 100, (1000, 100)) * np.random.binomial(1, 0.3, (1000, 100))
     X = X.astype(dtype)
     adata_orig = AnnData(X=count_matrix_format(X), dtype=dtype)
     total = X.sum()
