@@ -120,8 +120,7 @@ def dpt(
     if neighbors_key is None:
         neighbors_key = 'neighbors'
     if neighbors_key not in adata.uns:
-        raise ValueError(
-            'You need to run `pp.neighbors` and `tl.diffmap` first.')
+        raise ValueError('You need to run `pp.neighbors` and `tl.diffmap` first.')
     if 'iroot' not in adata.uns and 'xroot' not in adata.var:
         logg.warning(
             'No root cell found. To compute pseudotime, pass the index or '
@@ -136,29 +135,38 @@ def dpt(
         )
         _diffmap(adata, neighbors_key=neighbors_key)
     # start with the actual computation
-    dpt = DPT(adata, n_dcs=n_dcs, min_group_size=min_group_size,
-              n_branchings=n_branchings,
-              allow_kendall_tau_shift=allow_kendall_tau_shift,
-              neighbors_key=neighbors_key)
+    dpt = DPT(
+        adata,
+        n_dcs=n_dcs,
+        min_group_size=min_group_size,
+        n_branchings=n_branchings,
+        allow_kendall_tau_shift=allow_kendall_tau_shift,
+        neighbors_key=neighbors_key,
+    )
     start = logg.info(f'computing Diffusion Pseudotime using n_dcs={n_dcs}')
-    if n_branchings > 1: logg.info('    this uses a hierarchical implementation')
+    if n_branchings > 1:
+        logg.info('    this uses a hierarchical implementation')
     if dpt.iroot is not None:
         dpt._set_pseudotime()  # pseudotimes are distances from root point
-        adata.uns['iroot'] = dpt.iroot  # update iroot, might have changed when subsampling, for example
+        adata.uns[
+            'iroot'
+        ] = dpt.iroot  # update iroot, might have changed when subsampling, for example
         adata.obs['dpt_pseudotime'] = dpt.pseudotime
     # detect branchings and partition the data into segments
     if n_branchings > 0:
         dpt.branchings_segments()
         adata.obs['dpt_groups'] = pd.Categorical(
             values=dpt.segs_names.astype('U'),
-            categories=natsorted(np.array(dpt.segs_names_unique).astype('U')))
+            categories=natsorted(np.array(dpt.segs_names_unique).astype('U')),
+        )
         # the "change points" separate segments in the ordering above
         adata.uns['dpt_changepoints'] = dpt.changepoints
         # the tip points of segments
         adata.uns['dpt_grouptips'] = dpt.segs_tips
         # the ordering according to segments and pseudotime
         ordering_id = np.zeros(adata.n_obs, dtype=int)
-        for count, idx in enumerate(dpt.indices): ordering_id[idx] = count
+        for count, idx in enumerate(dpt.indices):
+            ordering_id[idx] = count
         adata.obs['dpt_order'] = ordering_id
         adata.obs['dpt_order_indices'] = dpt.indices
     logg.info(
@@ -166,11 +174,17 @@ def dpt(
         time=start,
         deep=(
             'added\n'
-            + ("    'dpt_pseudotime', the pseudotime (adata.obs)"
-               if dpt.iroot is not None else '')
-            + ("\n    'dpt_groups', the branching subgroups of dpt (adata.obs)"
-               "\n    'dpt_order', cell order (adata.obs)"
-               if n_branchings > 0 else '')
+            + (
+                "    'dpt_pseudotime', the pseudotime (adata.obs)"
+                if dpt.iroot is not None
+                else ''
+            )
+            + (
+                "\n    'dpt_groups', the branching subgroups of dpt (adata.obs)"
+                "\n    'dpt_order', cell order (adata.obs)"
+                if n_branchings > 0
+                else ''
+            )
         ),
     )
     return adata if copy else None
@@ -181,12 +195,23 @@ class DPT(Neighbors):
     Hierarchical Diffusion Pseudotime.
     """
 
-    def __init__(self, adata, n_dcs=None, min_group_size=0.01,
-                 n_branchings=0, allow_kendall_tau_shift=False, neighbors_key=None):
+    def __init__(
+        self,
+        adata,
+        n_dcs=None,
+        min_group_size=0.01,
+        n_branchings=0,
+        allow_kendall_tau_shift=False,
+        neighbors_key=None,
+    ):
         super().__init__(adata, n_dcs=n_dcs, neighbors_key=neighbors_key)
         self.flavor = 'haghverdi16'
         self.n_branchings = n_branchings
-        self.min_group_size = min_group_size if min_group_size >= 1 else int(min_group_size * self._adata.shape[0])
+        self.min_group_size = (
+            min_group_size
+            if min_group_size >= 1
+            else int(min_group_size * self._adata.shape[0])
+        )
         self.passed_adata = adata  # just for debugging purposes
         self.choose_largest_segment = False
         self.allow_kendall_tau_shift = allow_kendall_tau_shift
@@ -257,7 +282,11 @@ class DPT(Neighbors):
         #
         # let us define the tips of the whole data set
         if False:  # this is safe, but not compatible with on-the-fly computation
-            tips_all = np.array(np.unravel_index(np.argmax(self.distances_dpt), self.distances_dpt.shape))
+            tips_all = np.array(
+                np.unravel_index(
+                    np.argmax(self.distances_dpt), self.distances_dpt.shape
+                )
+            )
         else:
             if self.iroot is not None:
                 tip_0 = np.argmax(self.distances_dpt[self.iroot])
@@ -282,10 +311,15 @@ class DPT(Neighbors):
                 f'    branching {ibranch + 1}: split group {iseg}',
             )  # [third start end]
             # detect branching and update segs and segs_tips
-            self.detect_branching(segs, segs_tips,
-                                  segs_connects,
-                                  segs_undecided,
-                                  segs_adjacency, iseg, tips3)
+            self.detect_branching(
+                segs,
+                segs_tips,
+                segs_connects,
+                segs_undecided,
+                segs_adjacency,
+                iseg,
+                tips3,
+            )
         # store as class members
         self.segs = segs
         self.segs_tips = segs_tips
@@ -297,8 +331,9 @@ class DPT(Neighbors):
             self.segs_connects[i, seg_adjacency] = segs_connects[i]
         for i in range(len(segs)):
             for j in range(len(segs)):
-                self.segs_adjacency[i, j] = self.distances_dpt[self.segs_connects[i, j],
-                                                         self.segs_connects[j, i]]
+                self.segs_adjacency[i, j] = self.distances_dpt[
+                    self.segs_connects[i, j], self.segs_connects[j, i]
+                ]
         self.segs_adjacency = self.segs_adjacency.tocsr()
         self.segs_connects = self.segs_connects.tocsr()
 
@@ -307,16 +342,24 @@ class DPT(Neighbors):
         for n_edges in range(1, np.max(n_edges_per_seg) + 1):
             for iseg in range(self.segs_adjacency.shape[0]):
                 if n_edges_per_seg[iseg] == n_edges:
-                    neighbor_segs = self.segs_adjacency[iseg].todense().A1
-                    closest_points_other_segs = [seg[np.argmin(self.distances_dpt[self.segs_tips[iseg][0], seg])]
-                                                 for seg in self.segs]
+                    neighbor_segs = (  # noqa: F841  TODO Evaluate whether to assign the variable or not
+                        self.segs_adjacency[iseg].todense().A1
+                    )
+                    closest_points_other_segs = [
+                        seg[np.argmin(self.distances_dpt[self.segs_tips[iseg][0], seg])]
+                        for seg in self.segs
+                    ]
                     seg = self.segs[iseg]
-                    closest_points_in_segs = [seg[np.argmin(self.distances_dpt[tips[0], seg])]
-                                              for tips in self.segs_tips]
-                    distance_segs = [self.distances_dpt[closest_points_other_segs[ipoint], point]
-                                     for ipoint, point in enumerate(closest_points_in_segs)]
+                    closest_points_in_segs = [
+                        seg[np.argmin(self.distances_dpt[tips[0], seg])]
+                        for tips in self.segs_tips
+                    ]
+                    distance_segs = [
+                        self.distances_dpt[closest_points_other_segs[ipoint], point]
+                        for ipoint, point in enumerate(closest_points_in_segs)
+                    ]
                     # exclude the first point, the segment itself
-                    closest_segs = np.argsort(distance_segs)[1:n_edges+1]
+                    closest_segs = np.argsort(distance_segs)[1 : n_edges + 1]
                     # update adjacency matrix within the loop!
                     # self.segs_adjacency[iseg, neighbor_segs > 0] = 0
                     # self.segs_adjacency[iseg, closest_segs] = np.array(distance_segs)[closest_segs]
@@ -346,7 +389,8 @@ class DPT(Neighbors):
         allindices = np.arange(self._adata.shape[0], dtype=int)
         for iseg, seg in enumerate(segs):
             # do not consider too small segments
-            if segs_tips[iseg][0] == -1: continue
+            if segs_tips[iseg][0] == -1:
+                continue
             # restrict distance matrix to points in segment
             if not isinstance(self.distances_dpt, OnFlySymMatrix):
                 Dseg = self.distances_dpt[np.ix_(seg, seg)]
@@ -361,8 +405,13 @@ class DPT(Neighbors):
                         # take the inner tip, the "second tip" of the segment
                         for itip in range(2):
                             if (
-                                self.distances_dpt[segs_tips[jseg][1], segs_tips[iseg][itip]]
-                                < 0.5 * self.distances_dpt[segs_tips[iseg][~itip], segs_tips[iseg][itip]]
+                                self.distances_dpt[
+                                    segs_tips[jseg][1], segs_tips[iseg][itip]
+                                ]
+                                < 0.5
+                                * self.distances_dpt[
+                                    segs_tips[iseg][~itip], segs_tips[iseg][itip]
+                                ]
                             ):
                                 # logg.debug(
                                 #     '    group', iseg, 'with tip', segs_tips[iseg][itip],
@@ -371,8 +420,7 @@ class DPT(Neighbors):
                                 # logg.debug('    do not use the tip for "triangulation"')
                                 third_maximizer = itip
             # map the global position to the position within the segment
-            tips = [np.where(allindices[seg] == tip)[0][0]
-                    for tip in segs_tips[iseg]]
+            tips = [np.where(allindices[seg] == tip)[0][0] for tip in segs_tips[iseg]]
             # find the third point on the segment that has maximal
             # added distance from the two tip points
             dseg = Dseg[tips[0]] + Dseg[tips[1]]
@@ -397,17 +445,22 @@ class DPT(Neighbors):
             # if we did not normalize, there would be a danger of simply
             # assigning the highest score to the longest segment
             score = dseg[tips3[2]] / Dseg[tips3[0], tips3[1]]
-            score = len(seg) if self.choose_largest_segment else score  # simply the number of points
+            score = (
+                len(seg) if self.choose_largest_segment else score
+            )  # simply the number of points
             logg.debug(
-                f'    group {iseg} score {score} n_points {len(seg)} ' +
-                '(too small)' if len(seg) < self.min_group_size else '',
+                f'    group {iseg} score {score} n_points {len(seg)} ' + '(too small)'
+                if len(seg) < self.min_group_size
+                else '',
             )
-            if len(seg) <= self.min_group_size: score = 0
+            if len(seg) <= self.min_group_size:
+                score = 0
             # write result
             scores_tips[iseg, 0] = score
             scores_tips[iseg, 1:] = tips3
         iseg = np.argmax(scores_tips[:, 0])
-        if scores_tips[iseg, 0] == 0: return -1, None
+        if scores_tips[iseg, 0] == 0:
+            return -1, None
         tips3 = scores_tips[iseg, 1:].astype(int)
         return iseg, tips3
 
@@ -458,7 +511,7 @@ class DPT(Neighbors):
         indices = np.argsort(self.segs_names)
         segs_names = self.segs_names[indices]
         # find changepoints of segments
-        changepoints = np.arange(indices.size-1)[np.diff(segs_names) == 1] + 1
+        changepoints = np.arange(indices.size - 1)[np.diff(segs_names) == 1] + 1
         if self.iroot is not None:
             pseudotime = self.pseudotime[indices]
             for iseg, seg in enumerate(self.segs):
@@ -525,7 +578,9 @@ class DPT(Neighbors):
         segs_tips.insert(iseg, ssegs_tips[trunk])
         # append other segments
         segs += [seg for iseg, seg in enumerate(ssegs) if iseg != trunk]
-        segs_tips += [seg_tips for iseg, seg_tips in enumerate(ssegs_tips) if iseg != trunk]
+        segs_tips += [
+            seg_tips for iseg, seg_tips in enumerate(ssegs_tips) if iseg != trunk
+        ]
         if len(ssegs) == 4:
             # insert undecided cells at same position
             segs_undecided.pop(iseg)
@@ -535,8 +590,14 @@ class DPT(Neighbors):
         prev_connecting_segments = segs_adjacency[iseg].copy()
         if self.flavor == 'haghverdi16':
             segs_adjacency += [[iseg] for i in range(n_add)]
-            segs_connects += [seg_connects for iseg, seg_connects in enumerate(ssegs_connects) if iseg != trunk]
-            prev_connecting_points = segs_connects[iseg]
+            segs_connects += [
+                seg_connects
+                for iseg, seg_connects in enumerate(ssegs_connects)
+                if iseg != trunk
+            ]
+            prev_connecting_points = segs_connects[  # noqa: F841  TODO Evaluate whether to assign the variable or not
+                iseg
+            ]
             for jseg_cnt, jseg in enumerate(prev_connecting_segments):
                 iseg_cnt = 0
                 for iseg_new, seg_new in enumerate(ssegs):
@@ -553,7 +614,9 @@ class DPT(Neighbors):
                             segs_connects[kseg].append(idx)
                             break
                         iseg_cnt += 1
-            segs_adjacency[iseg] += list(range(len(segs_adjacency) - n_add, len(segs_adjacency)))
+            segs_adjacency[iseg] += list(
+                range(len(segs_adjacency) - n_add, len(segs_adjacency))
+            )
             segs_connects[iseg] += ssegs_connects[trunk]
         else:
             import networkx as nx
@@ -568,11 +631,29 @@ class DPT(Neighbors):
                 closest_points_in_kseg = []
                 for kseg in kseg_list:
                     reference_point_in_k = segs_tips[kseg][0]
-                    closest_points_in_jseg.append(segs[jseg][np.argmin(self.distances_dpt[reference_point_in_k, segs[jseg]])])
+                    closest_points_in_jseg.append(
+                        segs[jseg][
+                            np.argmin(
+                                self.distances_dpt[reference_point_in_k, segs[jseg]]
+                            )
+                        ]
+                    )
                     # do not use the tip in the large segment j, instead, use the closest point
-                    reference_point_in_j = closest_points_in_jseg[-1]  # segs_tips[jseg][0]
-                    closest_points_in_kseg.append(segs[kseg][np.argmin(self.distances_dpt[reference_point_in_j, segs[kseg]])])
-                    distances.append(self.distances_dpt[closest_points_in_jseg[-1], closest_points_in_kseg[-1]])
+                    reference_point_in_j = closest_points_in_jseg[
+                        -1
+                    ]  # segs_tips[jseg][0]
+                    closest_points_in_kseg.append(
+                        segs[kseg][
+                            np.argmin(
+                                self.distances_dpt[reference_point_in_j, segs[kseg]]
+                            )
+                        ]
+                    )
+                    distances.append(
+                        self.distances_dpt[
+                            closest_points_in_jseg[-1], closest_points_in_kseg[-1]
+                        ]
+                    )
                     # print(jseg, '(', segs_tips[jseg][0], closest_points_in_jseg[-1], ')',
                     #       kseg, '(', segs_tips[kseg][0], closest_points_in_kseg[-1], ') :', distances[-1])
                 idx = np.argmin(distances)
@@ -593,19 +674,42 @@ class DPT(Neighbors):
                 distances = []
                 closest_points_in_jseg = []
                 closest_points_in_kseg = []
-                jseg_list = [jseg for jseg in range(len(segs))
-                             if jseg != kseg and jseg not in prev_connecting_segments]
+                jseg_list = [
+                    jseg
+                    for jseg in range(len(segs))
+                    if jseg != kseg and jseg not in prev_connecting_segments
+                ]
                 for jseg in jseg_list:
                     reference_point_in_k = segs_tips[kseg][0]
-                    closest_points_in_jseg.append(segs[jseg][np.argmin(self.distances_dpt[reference_point_in_k, segs[jseg]])])
+                    closest_points_in_jseg.append(
+                        segs[jseg][
+                            np.argmin(
+                                self.distances_dpt[reference_point_in_k, segs[jseg]]
+                            )
+                        ]
+                    )
                     # do not use the tip in the large segment j, instead, use the closest point
-                    reference_point_in_j = closest_points_in_jseg[-1]  # segs_tips[jseg][0]
-                    closest_points_in_kseg.append(segs[kseg][np.argmin(self.distances_dpt[reference_point_in_j, segs[kseg]])])
-                    distances.append(self.distances_dpt[closest_points_in_jseg[-1], closest_points_in_kseg[-1]])
+                    reference_point_in_j = closest_points_in_jseg[
+                        -1
+                    ]  # segs_tips[jseg][0]
+                    closest_points_in_kseg.append(
+                        segs[kseg][
+                            np.argmin(
+                                self.distances_dpt[reference_point_in_j, segs[kseg]]
+                            )
+                        ]
+                    )
+                    distances.append(
+                        self.distances_dpt[
+                            closest_points_in_jseg[-1], closest_points_in_kseg[-1]
+                        ]
+                    )
                 idx = np.argmin(distances)
                 jseg_min = jseg_list[idx]
                 if jseg_min not in kseg_list:
-                    segs_adjacency_sparse = sp.sparse.lil_matrix((len(segs), len(segs)), dtype=float)
+                    segs_adjacency_sparse = sp.sparse.lil_matrix(
+                        (len(segs), len(segs)), dtype=float
+                    )
                     for i, seg_adjacency in enumerate(segs_adjacency):
                         segs_adjacency_sparse[i, seg_adjacency] = 1
                     G = nx.Graph(segs_adjacency_sparse)
@@ -685,7 +789,9 @@ class DPT(Neighbors):
         elif self.flavor == 'wolf17_bi' or self.flavor == 'wolf17_bi_un':
             ssegs = self._detect_branching_single_wolf17_bi(Dseg, tips)
         else:
-            raise ValueError('`flavor` needs to be in {"haghverdi16", "wolf17_tri", "wolf17_bi"}.')
+            raise ValueError(
+                '`flavor` needs to be in {"haghverdi16", "wolf17_tri", "wolf17_bi"}.'
+            )
         # make sure that each data point has a unique association with a segment
         masks = np.zeros((len(ssegs), Dseg.shape[0]), dtype=bool)
         for iseg, seg in enumerate(ssegs):
@@ -710,13 +816,19 @@ class DPT(Neighbors):
             for inewseg, newseg_tips in enumerate(ssegs_tips):
                 reference_point = newseg_tips[0]
                 # closest cell to the new segment within undecided cells
-                closest_cell = undecided_cells[np.argmin(Dseg[reference_point][undecided_cells])]
+                closest_cell = undecided_cells[
+                    np.argmin(Dseg[reference_point][undecided_cells])
+                ]
                 ssegs_connects[inewseg].append(closest_cell)
                 # closest cell to the undecided cells within new segment
-                closest_cell = ssegs[inewseg][np.argmin(Dseg[closest_cell][ssegs[inewseg]])]
+                closest_cell = ssegs[inewseg][
+                    np.argmin(Dseg[closest_cell][ssegs[inewseg]])
+                ]
                 ssegs_connects[-1].append(closest_cell)
             # also compute tips for the undecided cells
-            tip_0 = undecided_cells[np.argmax(Dseg[undecided_cells[0]][undecided_cells])]
+            tip_0 = undecided_cells[
+                np.argmax(Dseg[undecided_cells[0]][undecided_cells])
+            ]
             tip_1 = undecided_cells[np.argmax(Dseg[tip_0][undecided_cells])]
             ssegs_tips.append([tip_0, tip_1])
             ssegs_adjacency = [[3], [3], [3], [0, 1, 2]]
@@ -730,48 +842,74 @@ class DPT(Neighbors):
             # this is another strategy than for the undecided_cells
             # here it's possible to use the more symmetric procedure
             # shouldn't make much of a difference
-            closest_points[0, 1] = ssegs[1][np.argmin(Dseg[reference_point[0]][ssegs[1]])]
-            closest_points[1, 0] = ssegs[0][np.argmin(Dseg[reference_point[1]][ssegs[0]])]
-            closest_points[0, 2] = ssegs[2][np.argmin(Dseg[reference_point[0]][ssegs[2]])]
-            closest_points[2, 0] = ssegs[0][np.argmin(Dseg[reference_point[2]][ssegs[0]])]
-            closest_points[1, 2] = ssegs[2][np.argmin(Dseg[reference_point[1]][ssegs[2]])]
-            closest_points[2, 1] = ssegs[1][np.argmin(Dseg[reference_point[2]][ssegs[1]])]
+            closest_points[0, 1] = ssegs[1][
+                np.argmin(Dseg[reference_point[0]][ssegs[1]])
+            ]
+            closest_points[1, 0] = ssegs[0][
+                np.argmin(Dseg[reference_point[1]][ssegs[0]])
+            ]
+            closest_points[0, 2] = ssegs[2][
+                np.argmin(Dseg[reference_point[0]][ssegs[2]])
+            ]
+            closest_points[2, 0] = ssegs[0][
+                np.argmin(Dseg[reference_point[2]][ssegs[0]])
+            ]
+            closest_points[1, 2] = ssegs[2][
+                np.argmin(Dseg[reference_point[1]][ssegs[2]])
+            ]
+            closest_points[2, 1] = ssegs[1][
+                np.argmin(Dseg[reference_point[2]][ssegs[1]])
+            ]
             added_dist = np.zeros(3)
-            added_dist[0] = Dseg[closest_points[1, 0], closest_points[0, 1]] + Dseg[closest_points[2, 0], closest_points[0, 2]]
-            added_dist[1] = Dseg[closest_points[0, 1], closest_points[1, 0]] + Dseg[closest_points[2, 1], closest_points[1, 2]]
-            added_dist[2] = Dseg[closest_points[1, 2], closest_points[2, 1]] + Dseg[closest_points[0, 2], closest_points[2, 0]]
+            added_dist[0] = (
+                Dseg[closest_points[1, 0], closest_points[0, 1]]
+                + Dseg[closest_points[2, 0], closest_points[0, 2]]
+            )
+            added_dist[1] = (
+                Dseg[closest_points[0, 1], closest_points[1, 0]]
+                + Dseg[closest_points[2, 1], closest_points[1, 2]]
+            )
+            added_dist[2] = (
+                Dseg[closest_points[1, 2], closest_points[2, 1]]
+                + Dseg[closest_points[0, 2], closest_points[2, 0]]
+            )
             trunk = np.argmin(added_dist)
             ssegs_adjacency = [
-                [trunk] if i != trunk else
-                [j for j in range(3) if j != trunk]
+                [trunk] if i != trunk else [j for j in range(3) if j != trunk]
                 for i in range(3)
             ]
             ssegs_connects = [
-                [closest_points[i, trunk]] if i != trunk else
-                [closest_points[trunk, j] for j in range(3) if j != trunk]
+                [closest_points[i, trunk]]
+                if i != trunk
+                else [closest_points[trunk, j] for j in range(3) if j != trunk]
                 for i in range(3)
             ]
         else:
             trunk = 0
             ssegs_adjacency = [[1], [0]]
             reference_point_in_0 = ssegs_tips[0][0]
-            closest_point_in_1 = ssegs[1][np.argmin(Dseg[reference_point_in_0][ssegs[1]])]
+            closest_point_in_1 = ssegs[1][
+                np.argmin(Dseg[reference_point_in_0][ssegs[1]])
+            ]
             reference_point_in_1 = closest_point_in_1  # ssegs_tips[1][0]
-            closest_point_in_0 = ssegs[0][np.argmin(Dseg[reference_point_in_1][ssegs[0]])]
+            closest_point_in_0 = ssegs[0][
+                np.argmin(Dseg[reference_point_in_1][ssegs[0]])
+            ]
             ssegs_connects = [[closest_point_in_1], [closest_point_in_0]]
         return ssegs, ssegs_tips, ssegs_adjacency, ssegs_connects, trunk
 
     def _detect_branching_single_haghverdi16(self, Dseg, tips):
-        """Detect branching on given segment.
-        """
+        """Detect branching on given segment."""
         # compute branchings using different starting points the first index of
         # tips is the starting point for the other two, the order does not
         # matter
         ssegs = []
         # permutations of tip cells
-        ps = [[0, 1, 2],  # start by computing distances from the first tip
-              [1, 2, 0],  #             -"-                       second tip
-              [2, 0, 1]]  #             -"-                       third tip
+        ps = [
+            [0, 1, 2],  # start by computing distances from the first tip
+            [1, 2, 0],  #             -"-                       second tip
+            [2, 0, 1],  #             -"-                       third tip
+        ]
         for i, p in enumerate(ps):
             ssegs.append(self.__detect_branching_haghverdi16(Dseg, tips[p]))
         return ssegs
@@ -847,12 +985,10 @@ class DPT(Neighbors):
             # in terms of an ordering, such as exploited by the kendall
             # correlation method above
             imax = np.argmin(
-                Dseg[tips[0]][idcs]
-                + Dseg[tips[1]][idcs]
-                + Dseg[tips[2]][idcs]
+                Dseg[tips[0]][idcs] + Dseg[tips[1]][idcs] + Dseg[tips[2]][idcs]
             )
         # init list to store new segments
-        ssegs = []
+        ssegs = []  # noqa: F841  # TODO Look into this
         # first new segment: all points until, but excluding the branching point
         # increasing the following slightly from imax is a more conservative choice
         # as the criterion based on normalized distances, which follows below,
@@ -896,9 +1032,10 @@ class DPT(Neighbors):
         if a.ndim != b.ndim != 1:
             raise ValueError('a and b need to be one-dimensional arrays')
         import scipy as sp
+
         min_length = 5
         n = a.size
-        idx_range = np.arange(min_length, a.size-min_length-1, dtype=int)
+        idx_range = np.arange(min_length, a.size - min_length - 1, dtype=int)
         corr_coeff = np.zeros(idx_range.size)
         pos_old = sp.stats.kendalltau(a[:min_length], b[:min_length])[0]
         neg_old = sp.stats.kendalltau(a[min_length:], b[min_length:])[0]
@@ -909,14 +1046,14 @@ class DPT(Neighbors):
                 # the second subsequence
                 diff_pos, diff_neg = self._kendall_tau_diff(a, b, i)
                 pos = pos_old + self._kendall_tau_add(i, diff_pos, pos_old)
-                neg = neg_old + self._kendall_tau_subtract(n-i, diff_neg, neg_old)
+                neg = neg_old + self._kendall_tau_subtract(n - i, diff_neg, neg_old)
                 pos_old = pos
                 neg_old = neg
             if False:
                 # computation using sp.stats.kendalltau, takes much longer!
                 # just for debugging purposes
-                pos = sp.stats.kendalltau(a[:i+1], b[:i+1])[0]
-                neg = sp.stats.kendalltau(a[i+1:], b[i+1:])[0]
+                pos = sp.stats.kendalltau(a[: i + 1], b[: i + 1])[0]
+                neg = sp.stats.kendalltau(a[i + 1 :], b[i + 1 :])[0]
             if False:
                 # the following is much slower than using sp.stats.kendalltau,
                 # it is only good for debugging because it allows to compute the
@@ -947,7 +1084,7 @@ class DPT(Neighbors):
         tau_old
             Kendall rank correlation of the old sequence.
         """
-        return 2./(len_old+1)*(float(diff_pos)/len_old-tau_old)
+        return 2.0 / (len_old + 1) * (float(diff_pos) / len_old - tau_old)
 
     def _kendall_tau_subtract(self, len_old: int, diff_neg: int, tau_old: float):
         """Compute Kendall tau delta.
@@ -963,7 +1100,7 @@ class DPT(Neighbors):
         tau_old
             Kendall rank correlation of the old sequence.
         """
-        return 2./(len_old-2)*(-float(diff_neg)/(len_old-1)+tau_old)
+        return 2.0 / (len_old - 2) * (-float(diff_neg) / (len_old - 1) + tau_old)
 
     def _kendall_tau_diff(self, a: np.ndarray, b: np.ndarray, i) -> Tuple[int, int]:
         """Compute difference in concordance of pairs in split sequences.
