@@ -31,7 +31,8 @@ def _choose_representation(adata, use_rep=None, n_pcs=None, silent=False):
             if 'X_pca' in adata.obsm.keys():
                 if n_pcs is not None and n_pcs > adata.obsm['X_pca'].shape[1]:
                     raise ValueError(
-                        '`X_pca` does not have enough PCs. Rerun `sc.pp.pca` with adjusted `n_comps`.')
+                        '`X_pca` does not have enough PCs. Rerun `sc.pp.pca` with adjusted `n_comps`.'
+                    )
                 X = adata.obsm['X_pca'][:, :n_pcs]
                 logg.info(f'    using \'X_pca\' with n_pcs = {X.shape[1]}')
             else:
@@ -55,7 +56,8 @@ def _choose_representation(adata, use_rep=None, n_pcs=None, silent=False):
         else:
             raise ValueError(
                 'Did not find {} in `.obsm.keys()`. '
-                'You need to compute it first.'.format(use_rep))
+                'You need to compute it first.'.format(use_rep)
+            )
     settings.verbosity = verbosity  # resetting verbosity
     return X
 
@@ -75,8 +77,7 @@ def preprocess_with_pca(adata, n_pcs: Optional[int] = None, random_state=0):
     elif n_pcs is None and 'X_pca' in adata.obsm_keys():
         logg.info(f'    using \'X_pca\' with n_pcs = {adata.obsm["X_pca"].shape[1]}')
         return adata.obsm['X_pca']
-    elif ('X_pca' in adata.obsm_keys()
-          and adata.obsm['X_pca'].shape[1] >= n_pcs):
+    elif 'X_pca' in adata.obsm_keys() and adata.obsm['X_pca'].shape[1] >= n_pcs:
         logg.info(f'    using \'X_pca\' with n_pcs = {n_pcs}')
         return adata.obsm['X_pca'][:, :n_pcs]
     else:
@@ -92,7 +93,9 @@ def preprocess_with_pca(adata, n_pcs: Optional[int] = None, random_state=0):
             return adata.X
 
 
-def get_init_pos_from_paga(adata, adjacency=None, random_state=0, neighbors_key=None, obsp=None):
+def get_init_pos_from_paga(
+    adata, adjacency=None, random_state=0, neighbors_key=None, obsp=None
+):
     np.random.seed(random_state)
     if adjacency is None:
         adjacency = _choose_graph(adata, obsp, neighbors_key)
@@ -110,10 +113,11 @@ def get_init_pos_from_paga(adata, adjacency=None, random_state=0, neighbors_key=
                 noise = np.random.random((len(subset[subset]), 2))
                 dist = pos[i] - pos[nearest_neighbor]
                 noise = noise * dist
-                init_pos[subset] = group_pos - 0.5*dist + noise
+                init_pos[subset] = group_pos - 0.5 * dist + noise
             else:
                 init_pos[subset] = group_pos
     else:
-        raise ValueError('Plot PAGA first, so that adata.uns[\'paga\']'
-                         'with key \'pos\'.')
+        raise ValueError(
+            'Plot PAGA first, so that adata.uns[\'paga\']' 'with key \'pos\'.'
+        )
     return init_pos
